@@ -42,5 +42,17 @@ before rebless_instance_away => sub {
     $self->_untrack_instance($instance);
 };
 
+around _inline_generate_instance => sub {
+    my $orig = shift;
+    my ($self, $var, $class_var) = @_;
+
+    my @generate_instance = $orig->(@_);
+
+    return (
+        @generate_instance,
+        'Moose::Meta::Class->initialize(' . $class_var . ')->_track_instance(' . $var . ');',
+    );
+};
+
 1;
 
